# Readme
## Quantitative analysis of spectroscopic Low Energy Electron Microscopy data: High-dynamic range imaging, drift correction and cluster analysis
Data used in the article De Jong, T. A., Kok, D. N. L., Van der Torren, A. J. H., Schopmans, H., Tromp, R. M., van der Molen, S. J., & Jobst, J., "Quantitative analysis of spectroscopic Low Energy Electron Microscopy data: High-dynamic range imaging, drift correction and cluster analysis" Ultramicroscopy (2019).

#### Corresponding Author:

Tobias A. de Jong

##### Contact Information:

jongt@physics.leidenuniv.nl
Huygens-Kamerlingh Onnes Laboratorium
Leiden University
P.O. Box 9504
NL-2300 RA Leiden
The Netherlands


### Introduction
This dataset contains the Low Energy Electon Microscopy (LEEM) data underlying the paper which describes how to apply High-Dynamic range imaging, drift correction and cluster analysis to such data.
It contains the calibration data for the ESCHER Low Energy Electron Microscopy setup at Leiden University, as well as two spectroscopic datasets which serve as example datasets and finally benchmark results of the presented drift correction algorithm.
All data was acquired on the ESCHER LEEM facility at Leiden University and is labeled according to date and time of the measurement and a name.
The supporting Python code is available separately on Github https://github.com/TAdeJong/LEEM-analysis.

### Data files
The dataset contains the following files:
* `README.md`: This readme
* Calibration data
    * `20171205_115846_0.66um_475.8_DC.nc`: Dark count image without any electron illumination
    * `20171205_100540_0.66um_479.2_sweepCHANNELPLATE_SET_lowintensity_v2.nc`: lowest intensity HDR calibration
    * `20171205_103440_0.66um_479.2_sweepCHANNELPLATE_SET_highintensity.nc`: middle intensity HDR calibration
    * `20171205_143305_31um_474.2_sweepCHANNELPLATE_SET_higherintensity.nc`: high intensity HDR calibration
* Example data
    * `20171120_160356_3.5um_591.4_IVhdr.nc`: Bright Field spectroscopic data of different layer counts of graphene grown on Silicon Carbide
    * `20171120_215555_3.5um_583.1_IVhdr_DF2.nc`: Dark Field spectroscopic dataset of the same area
    * `20190509_142203_3.5um_561.5_IVhdr_BILAYER.nc`: An averaged spectrum with HDR imaging
    * `20190509_155656_3.5um_562.1_IV_BILAYER.nc`: An equivalent spectrum to the previous without HDR imaging
* Intermediate processed data, for _each_ of the spectroscopic data:
    * `_detectorcorrected.nc`: The stack of data corrected for detector effects.
    * `_driftcorrected.nc`: The stack of data corrected for detector effects and image drift. Image drift is corrected with `stride = 1`, using all images to determine the shift.
* Benchmark results
    * `accuracy_result_reference.nc`: Calculated shifts for different settings of the parameters
    * `benchmarkresult_reference.nc`: Timings for different lengths of dataset and different values of smoothing parameter

Experimental details for the spectroscopic data are discussed in the following paper: 
T. A. de Jong, E. E. Krasovskii, C. Ott, R. M. Tromp, S. J. van der Molen, J. Jobst, _Intrinsic stacking  domains in graphene on silicon carbide: A pathway for intercalation_, *Physical Review Materials* 2 (10) (2018) 104005. (https://doi.org/10.1103/PhysRevMaterials.2.104005)

### Data format
#### netCDF4 files
The netCDF4 files each contain a `Intensity` variable containing the images, expressed in coordinates `time`, `x` and `y`.
In addition, various measured or set quantities are given as extra data variables, each with an attribute `units` if appropriate. The following quantities are present:
* `Pressure` Pressure measured in the sample room in millibar.
* `Multiplier` Multiplier used to scale the intensity from its real value to the stored value. Divide the stored Intensity by the multiplier to regain the original magnitude.
* `Energy` The measured landing energy or relative sample potential.
* `Energy_set` The set landing energy or relative sample potential.
* `Temperature` Temperature of the sample measured by pyrometer.
* `MCP_bias` High voltage bias on the Micro Channelplate detector
* `mcount` Number of exposures accumulated in a single image
 
### Example code and use in Figures

Python code showcasing the calibration, exploring the data and generating the figures in the paper is available on Github https://github.com/TAdeJong/LEEM-analysis, https://doi.org/10.5281/zenodo.3539538.
